@@ -596,8 +596,16 @@ class ContainerApp(Resource):  # pylint: disable=too-many-instance-attributes
         # Creating a tag for the image using the current time to avoid overwriting customer's existing images
         now = datetime.now()
         tag_now_suffix = str(now).replace(" ", "").replace("-", "").replace(".", "").replace(":", "")
-        image_name_with_tag = image_name + ":{}".format(tag_now_suffix)
-        self.image = self.registry_server + "/" + image_name_with_tag
+
+        if ":" in image_name.split("/")[-1]:
+            image_name_with_tag = image_name
+        else:
+            image_name_with_tag = image_name + ":{}".format(tag_now_suffix)
+
+        if not image_name_with_tag.startswith(self.registry_server):
+            self.image = self.registry_server + "/" + image_name_with_tag
+        else:
+            self.image = image_name_with_tag
 
         if build_from_source:
             logger.warning(
@@ -820,23 +828,31 @@ def _get_dockerfile_content(repo, branch, token, source, context_path, dockerfil
 def _get_app_env_and_group(
         cmd, name, resource_group: "ResourceGroup", env: "ContainerAppEnvironment", location
 ):
+    matched_apps = []
+    # If no resource group is provided, we need to search for the app in all resource groups
     if not resource_group.name and not resource_group.exists:
         matched_apps = [c for c in list_containerapp(cmd) if c["name"].lower() == name.lower()]
-        if env.name:
-            matched_apps = [c for c in matched_apps if
-                            parse_resource_id(c["properties"]["environmentId"])["name"].lower() == env.name.lower()]
-        if location:
-            matched_apps = [c for c in matched_apps if format_location(c["location"]) == format_location(location)]
-        if len(matched_apps) == 1:
-            resource_group.name = parse_resource_id(matched_apps[0]["id"])[
-                "resource_group"
-            ]
-            env.set_name(matched_apps[0]["properties"]["environmentId"])
-        elif len(matched_apps) > 1:
-            raise ValidationError(
-                f"There are multiple containerapps with name {name} on the subscription. "
-                "Please specify which resource group your Containerapp is in."
-            )
+
+    # If a resource group is provided, we need to search for the app in that resource group
+    if resource_group.name and resource_group.exists:
+        matched_apps = [c for c in list_containerapp(cmd, resource_group_name=resource_group.name) if
+                        c["name"].lower() == name.lower()]
+
+    if env.name:
+        matched_apps = [c for c in matched_apps if
+                        parse_resource_id(c["properties"]["environmentId"])["name"].lower() == env.name.lower()]
+    if location:
+        matched_apps = [c for c in matched_apps if format_location(c["location"]) == format_location(location)]
+    if len(matched_apps) == 1:
+        resource_group.name = parse_resource_id(matched_apps[0]["id"])[
+            "resource_group"
+        ]
+        env.set_name(matched_apps[0]["properties"]["environmentId"])
+    elif len(matched_apps) > 1:
+        raise ValidationError(
+            f"There are multiple containerapps with name {name} on the subscription. "
+            "Please specify which resource group your Containerapp is in."
+        )
 
 
 def _get_env_and_group_from_log_analytics(
