@@ -456,6 +456,35 @@ examples:
     crafted: true
 """
 
+helps['mysql flexible-server maintenance'] = """
+type: group
+short-summary: Manage maintenance on a flexible server.
+"""
+
+helps['mysql flexible-server maintenance reschedule'] = """
+type: command
+short-summary: Reschedule the ongoing planned maintenance of a flexible server.
+examples:
+  - name: reschedule a existing maintenance '_T9Q-TS8' of the server 'testserver' under resource gruop 'testgroup' to a new start time 'UTC 20240601 09:00:00'
+    text: az mysql flexible-server maintenance reschedule --resource-group testgroup --server-name testserver --maintenance-name _T9Q-TS8 --start-time 2024-06-01T09:00:00Z
+"""
+
+helps['mysql flexible-server maintenance list'] = """
+type: command
+short-summary: List all of the maintenances of a flexible server.
+examples:
+  - name: List all of the maintenances of mysql flexible server 'testserver' under resource group 'testgroup'.
+    text: az mysql flexible-server maintenance list --resource-group testgroup --server-name testserver
+"""
+
+helps['mysql flexible-server maintenance show'] = """
+type: command
+short-summary: Get the specific maintenance of a flexible server by maintenance name.
+examples:
+  - name: Get a maintenance of mysql flexible server 'testserver' under resource group 'testgroup', with maintenance name '_T9Q-TS8'
+    text: az mysql flexible-server maintenance show --resource-group testgroup --server-name testserver --maintenance-name _T9Q-TS8
+"""
+
 helps['mysql flexible-server wait'] = """
 type: command
 short-summary: Wait for the flexible server to satisfy certain conditions.
