@@ -230,6 +230,25 @@ def validate_dns_record_type(namespace):
             return
 
 
+def validate_managed_identity_resource_id(resource_id):
+    if resource_id.lower() == 'none':
+        return True
+    parts = resource_id.split('/')
+    if len(parts) != 9:
+        raise ValueError(
+            'Invalid resource ID format for a managed identity. It should be in the format:'
+            '/subscriptions/{subscription}/resourceGroups/{resource_group}/providers/'
+            'Microsoft.ManagedIdentity/userAssignedIdentities/{identity_name}')
+
+    if (parts[1] != 'subscriptions' or parts[3] != 'resourceGroups' or parts[5] != 'providers' or
+            parts[6] != 'Microsoft.ManagedIdentity' or parts[7] != 'userAssignedIdentities'):
+        raise ValueError(
+            'Invalid resource ID format for a managed identity. It should contain subscriptions,'
+            'resourceGroups, providers/Microsoft.ManagedIdentity/userAssignedIdentities'
+            'in the correct order.')
+    return True
+
+
 def validate_user_assigned_identity(cmd, namespace):
     from msrestazure.tools import is_valid_resource_id, resource_id
 
